@@ -4,5 +4,5 @@ author = 'Benjamin Wohlwend'
 author_email = 'piquadrat@gmail.com'
 description = "celery store backend and kombu transport for redis that supports connections via unix sockets"
 version = __import__(package_name).__version__
-project_url = 'http://github.com/celery-redis-unixsocket/%s' % name
+project_url = 'http://github.com/piquadrat/%s' % name
 license = 'BSD'
